@@ -132,9 +132,14 @@ sub _split_body_and_directives {
             # reset the directives on blank lines
             if ($line =~ m/^\s*$/s) {
                 $lastdirective = undef;
-            } elsif ($line =~ m/^\#([A-Za-z0-9]+)\s+(.+)$/s) {
+            } elsif ($line =~ m/^\#([A-Za-z0-9]+)(\s+(.+))?$/s) {
                 my $dir = $1;
-                $directives{$dir} = $2;
+                if ($2) {
+                    $directives{$dir} = $3;
+                }
+                else {
+                    $directives{$dir} = '';
+                }
                 $lastdirective = $dir;
             } elsif ($lastdirective) {
                 $directives{$lastdirective} .= $line;
