@@ -29,7 +29,9 @@ pretty much internal only (and underdocumented).
   
   % avoid breakage on multiple <br><br> and avoid the next [] to be eaten
   \newcommand*{\forcelinebreak}{~\\\relax}
-  
+  % this also works
+  % \newcommand*{\forcelinebreak}{\strut\\{}}
+
   \newcommand*{\hairline}{%
     \bigskip%
     \noindent \hrulefill%
@@ -832,13 +834,18 @@ sub manage_table_ltx {
     }
     # then we loop over what we have. First head, then body, and
     # finally foot
-    
-    my $textable =<<'EOF';
-\noindent
- \begin{minipage}[t]{\textwidth}
-\smallskip
-\centering
-EOF
+    my $has_caption;
+    if (defined $table->{caption} and $table->{caption} ne '') {
+        $has_caption = 1;
+    }
+    my $textable = '';
+    if ($has_caption) {
+        $textable .= "\\begin{table}[htbp!]\n";
+    }
+    else {
+        $textable .= "\\bigskip\n\\noindent\n";
+    }
+    $textable .= " \\begin{minipage}[t]{\\textwidth}\n";
     $textable .= "\\begin{tabularx}{\\textwidth}{" ;
     $textable .= "|X" x $table->{counter};
     $textable .= "|}\n";
@@ -852,12 +859,18 @@ EOF
         $textable .= "\\hline\n" . join("", @foot);
     }
     $textable .= "\\hline\n\\end{tabularx}\n";
-    if (defined $table->{caption} and $table->{caption} ne "") {
-        $textable .= "\n\\medskip\n" .
-          $self->manage_regular($table->{caption}) . "\n\n\\medskip\n\n";
+    if ($has_caption) {
+        $textable .= "\n\\caption[]{" .
+          $self->manage_regular($table->{caption}) . "}\n";
     }
-    $textable .= "\\bigskip\n";
-    $textable .= "\\end{minipage}\n\n";
+    $textable .= "\\end{minipage}\n";
+    if ($has_caption) {
+        $textable .= "\\end{table}\n";
+    }
+    else {
+        $textable .= "\\bigskip\n";
+    }
+    $textable .= "\n";
     # print $textable;
     return $textable;
 }
